@@ -7,9 +7,7 @@
 ;;;; Programmer:    Kevin M. Rosenberg
 ;;;; Date Started:  Feb 2002
 ;;;;
-;;;; $Id$
-;;;;
-;;;; This file, part of UFFI, is Copyright (c) 2005 by Kevin M. Rosenberg
+;;;; This file, part of UFFI, is Copyright (c) 2002-2010 by Kevin M. Rosenberg
 ;;;;
 ;;;; *************************************************************************
 
@@ -146,7 +144,7 @@
         #+(or cmu scl sbcl)
         `(%def-function ,names ,args
           ,@(if returning (list :returning returning) (values)))
-        #+(and lispworks lispworks5)
+        #+(or lispworks5 lispworks6)
         (multiple-value-bind (name-pair fname lisp-name)
             (preprocess-names names)
           `(progn
@@ -161,7 +159,7 @@
                                       ((member (first arg) out :key #'first)
                                        t)))
                           args)))))
-        #+(and lispworks (not lispworks5))
+        #+(and lispworks (not lispworks5) (not lispworks 6))
         `(%def-function ,names ,(convert-lispworks-args args)
           ,@(if module (list :module module) (values))
           ,@(if returning (list :returning returning) (values)))
