@@ -7,9 +7,7 @@
 ;;;; Programmer:    Kevin M. Rosenberg
 ;;;; Date Started:  Feb 2002
 ;;;;
-;;;; $Id$
-;;;;
-;;;; This file, part of UFFI, is Copyright (c) 2002-2005 by Kevin M. Rosenberg
+;;;; This file, part of UFFI, is Copyright (c) 2002-2010 by Kevin M. Rosenberg
 ;;;;
 ;;;; *************************************************************************
 
@@ -139,8 +137,8 @@ an array of TYPE with size SIZE. The TYPE parameter is evaluated."
   `(if (integerp ,obj) ,obj (char-code ,obj)))
 
 (defmacro ensure-char-storable (obj)
-  #+(or digitool (and lispworks (not lispworks5))) obj
-  #+(or allegro cmu lispworks5 openmcl sbcl scl)
+  #+(or digitool (and lispworks (not lispworks5) (not lispworks6))) obj
+  #+(or allegro cmu lispworks5 lispworks6 openmcl sbcl scl)
   `(char-code ,obj))
 
 (defmacro pointer-address (obj)
