@@ -7,9 +7,7 @@
 ;;;; Author:        Kevin M. Rosenberg
 ;;;; Date Started:  Feb 2002
 ;;;;
-;;;; $Id$
-;;;;
-;;;; This file, part of UFFI, is Copyright (c) 2002-2005 by Kevin M. Rosenberg
+;;;; This file, part of UFFI, is Copyright (c) 2002-2010 by Kevin M. Rosenberg
 ;;;;
 ;;;; *************************************************************************
 
@@ -28,6 +26,8 @@
           "z"
           (list (pathname-directory *load-pathname*)
                 "/usr/local/lib/" #+(or 64bit x86-64) "/usr/lib64/"
+                "/usr/lib32/"
+                "/opt/local/lib/"
                 "/usr/lib/" "/zlib/"))
          :module "zlib"
          :supporting-libraries '("c"))
